@@ -2,8 +2,6 @@
 
 namespace Doctrine\Persistence;
 
-use function interface_exists;
-
 /**
  * Contract covering connection for a Doctrine persistence layer ManagerRegistry class to implement.
  */
@@ -39,5 +37,3 @@ interface ConnectionRegistry
      */
     public function getConnectionNames();
 }
-
-interface_exists(\Doctrine\Common\Persistence\ConnectionRegistry::class);
