@@ -4,7 +4,6 @@ namespace Doctrine\Persistence\Event;
 
 use Doctrine\Common\EventArgs;
 use Doctrine\Persistence\ObjectManager;
-use function class_exists;
 
 /**
  * Provides event arguments for the preFlush event.
@@ -29,5 +28,3 @@ class ManagerEventArgs extends EventArgs
         return $this->objectManager;
     }
 }
-
-class_exists(\Doctrine\Common\Persistence\Event\ManagerEventArgs::class);
